sd_via_median_estimator: Compute standard deviation via median estimator.
Description
Compute standard deviation via median estimator.
Please refer to formula #2 in Engbert & Kliegl (2003).
Falls back on mean estimator, if computed standard deviation
is smaller than .Machine$double.eps. Raises an error
if the results using the mean estimator is still smaller than
.Machine$double.eps.